# Copyright (c) 2003 Sylvain Thenault (thenault@nerim.net)
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

__author__ = u"Sylvain Thenault"
__revision__ = "$Id: __init__.py,v 1.5 2003/09/12 11:54:48 syt Exp $"

from logilab.common.interface import Interface

from astng_objects import *
from manager import ASTNG_MANAGER, ASTNGBuildingException

class IASTNGVisitor(Interface):
    """interface for checker which prefers receive events according to
    statement type
    """
    
    def visit_module(self, node):
        """module node hook"""
        raise NotImplementedError()
    
    def visit_classdef(self, node):
        """class node hook"""
        raise NotImplementedError()
    
    def visit_funcdef(self, node):
        """function/method node hook"""
        raise NotImplementedError()
    
    def visit_ifstmt(self, node):
        """if statement node hook"""
        raise NotImplementedError()
    
    def visit_elifstmt(self, node):
        """elif statement node hook"""
        raise NotImplementedError()
    
    def visit_elsestmt(self, node):
        """else statement node hook"""
        raise NotImplementedError()
    
    def visit_whilestmt(self, node):
        """while statement node hook"""
        raise NotImplementedError()
    
    def visit_exceptstmt(self, node):
        """except statement node hook"""
        raise NotImplementedError()
    
    def visit_forstmt(self, node):
        """for statement node hook"""
        raise NotImplementedError()
    
    def visit_trystmt(self, node):
        """try statement node hook"""
        raise NotImplementedError()
    
    def visit_finallystmt(self, node):
        """finally statement node hook"""
        raise NotImplementedError()
    
    def visit_passstmt(self, node):
        """pass statement node hook"""
        raise NotImplementedError()
    
    def visit_continuestmt(self, node):
        """continue statement node hook"""
        raise NotImplementedError()
    
    def visit_breakstmt(self, node):
        """break statement node hook"""
        raise NotImplementedError()
    
    def visit_raisestmt(self, node):
        """raise statement node hook"""
        raise NotImplementedError()
    
    def visit_assertstmt(self, node):
        """assert statement node hook"""
        raise NotImplementedError()
    
    def visit_globalstmt(self, node):
        """global statement node hook"""
        raise NotImplementedError()
    
    def visit_delstmt(self, node):
        """del statement node hook"""
        raise NotImplementedError()
    
    def visit_printstmt(self, node):
        """print statement node hook"""
        raise NotImplementedError()
    
    def visit_returnstmt(self, node):
        """return statement node hook"""
        raise NotImplementedError()
    
    def visit_yieldstmt(self, node):
        """yield statement node hook"""
        raise NotImplementedError()
    
    def visit_execstmt(self, node):
        """exec statement node hook"""
        raise NotImplementedError()
    
    def visit_importstmt(self, node):
        """import statement node hook"""
        raise NotImplementedError()
    
    def visit_expressionstmt(self, node):
        """expression statement node hook"""
        raise NotImplementedError()
    
    def visit_assignmentstmt(self, node):
        """assigment statement node hook"""
        raise NotImplementedError()
    
    def visit_stringstmt(self, node):
        """string statement node hook"""
        raise NotImplementedError()


class ASTNGHandler:
    """ default handler for ASTNG visitors
    
    (pass to each event)
    """
    __implements__ = IASTNGVisitor
    
    def visit_module(self, node):
        """module node hook"""
    
    def visit_classdef(self, node):
        """class node hook"""
    
    def visit_funcdef(self, node):
        """function/method node hook"""
    
    def visit_ifstmt(self, node):
        """if statement node hook"""
    
    def visit_elifstmt(self, node):
        """elif statement node hook"""
    
    def visit_elsestmt(self, node):
        """else statement node hook"""
    
    def visit_whilestmt(self, node):
        """while statement node hook"""
    
    def visit_exceptstmt(self, node):
        """except statement node hook"""
    
    def visit_forstmt(self, node):
        """for statement node hook"""
    
    def visit_trystmt(self, node):
        """try statement node hook"""
    
    def visit_finallystmt(self, node):
        """finally statement node hook"""
    
    def visit_passstmt(self, node):
        """pass statement node hook"""
    
    def visit_continuestmt(self, node):
        """continue statement node hook"""
    
    def visit_breakstmt(self, node):
        """break statement node hook"""
    
    def visit_raisestmt(self, node):
        """raise statement node hook"""
    
    def visit_assertstmt(self, node):
        """assert statement node hook"""
    
    def visit_globalstmt(self, node):
        """global statement node hook"""
    
    def visit_delstmt(self, node):
        """del statement node hook"""
    
    def visit_printstmt(self, node):
        """print statement node hook"""
    
    def visit_returnstmt(self, node):
        """return statement node hook"""
    
    def visit_yieldstmt(self, node):
        """yield statement node hook"""
    
    def visit_execstmt(self, node):
        """exec statement node hook"""
    
    def visit_importstmt(self, node):
        """import statement node hook"""
    
    def visit_expressionstmt(self, node):
        """expression statement node hook"""
    
    def visit_assignmentstmt(self, node):
        """assigment statement node hook"""
    
    def visit_stringstmt(self, node):
        """string statement node hook"""

__all__ = ('IASTNGVisitor', 'ASTNGHandler',
           'ASTNGBuildingException', 'ASTNGManager')
